#!/usr/bin/env python

from imiptools.data import get_freebusy_period, get_datetime_item, get_value, get_value_map, parse_object
from imiptools.dates import format_datetime, get_default_timezone
from imiptools.profile import Preferences
from imip_store import FileStore, FilePublisher
import sys

try:
    user = sys.argv[1]
except IndexError:
    print >>sys.stderr, "Need a user."
    sys.exit(1)

preferences = Preferences(user)
tzid = preferences.get("TZID") or get_default_timezone()

s = FileStore()
p = FilePublisher()

events = set(s.get_events(user))
cancelled = s.get_cancellations(user) or []

events.difference_update(cancelled)

objs = []
for i in events:
    print >>sys.stderr, i
    objs.append(parse_object(s.get_event(user, i), "utf-8"))

fb = []
for obj in objs:
    if not obj:
        continue
    details, details_attr = obj.values()[0]

    participants = {}
    participants.update(get_value_map(details, "ATTENDEE"))
    participants.update(get_value_map(details, "ORGANIZER"))

    for participant, participant_attr in participants.items():
        if participant == user:
            if participant_attr.get("PARTSTAT") != "DECLINED":
                dtstart, dtstart_attr = get_datetime_item(details, "DTSTART")
                dtend, dtend_attr = get_datetime_item(details, "DTEND")
                event_tzid = dtstart_attr.get("TZID") or dtend_attr.get("TZID") or tzid
                dtstart, dtend = get_freebusy_period(dtstart, dtend, event_tzid)
                fb.append((format_datetime(dtstart),
                           format_datetime(dtend),
                           get_value(details, "UID"),
                           get_value(details, "TRANSP")))
            break

fb.sort()

s.set_freebusy(user, fb)
p.set_freebusy(user, fb)

# vim: tabstop=4 expandtab shiftwidth=4
